import { Component, Host, h, Element, State, Prop, Watch, Event } from '@stencil/core';
import { debounce } from '@deckdeckgo/utils';
import { containerSize } from '../utils/size.utils';
export class DeckGoDoc {
  constructor() {
    this.size = 'A4';
    this.orientation = 'portrait';
    this.debounceInitSize = debounce(() => this.initSize(), 100);
  }
  componentDidLoad() {
    this.initSize();
    this.initWindowResize();
  }
  disconnectedCallback() {
    window === null || window === void 0 ? void 0 : window.removeEventListener('resize', this.debounceInitSize);
  }
  onZoomChange() {
    this.debounceInitSize();
  }
  initSize() {
    const onRender = (_mutations, observer) => {
      observer.disconnect();
      this.sizeDidChange.emit(this.docSize);
    };
    const docObserver = new MutationObserver(onRender);
    docObserver.observe(this.el, { attributes: true });
    this.docSize = containerSize({ embedded: true, container: this.el });
  }
  initWindowResize() {
    window === null || window === void 0 ? void 0 : window.addEventListener('resize', this.debounceInitSize);
  }
  render() {
    const style = Object.assign(Object.assign({}, (this.zoom && { '--doc-zoom': `${this.zoom}` })), (this.docSize && { '--doc-width': `${this.docSize.width}px`, '--doc-height': `${this.docSize.height}px` }));
    return (h(Host, { style: style },
      h("slot", null)));
  }
  static get is() { return "deckgo-doc"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["doc.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["doc.css"]
  }; }
  static get properties() { return {
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'A4' | 'A3' | 'A5'",
        "resolved": "\"A3\" | \"A4\" | \"A5\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "size",
      "reflect": true,
      "defaultValue": "'A4'"
    },
    "orientation": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'portrait' | 'landscape'",
        "resolved": "\"landscape\" | \"portrait\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "orientation",
      "reflect": true,
      "defaultValue": "'portrait'"
    },
    "zoom": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "zoom",
      "reflect": false
    }
  }; }
  static get states() { return {
    "docSize": {}
  }; }
  static get events() { return [{
      "method": "sizeDidChange",
      "name": "sizeDidChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "{width: number; height: number}",
        "resolved": "{ width: number; height: number; }",
        "references": {}
      }
    }]; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "zoom",
      "methodName": "onZoomChange"
    }]; }
}
