import { lazyLoadSelectedImages, lazyLoadSelectedLazyImagesComponent } from '@deckdeckgo/utils';
export class DeckdeckgoDeckBackgroundUtils {
  // Lazy load images from slot=background
  static lazyBackgroundImages(el) {
    return new Promise(async (resolve) => {
      const promises = [];
      promises.push(this.lazyBackgroundImgTags(el));
      promises.push(this.lazyBackgroundImgComponents(el));
      await Promise.all(promises);
      resolve();
    });
  }
  static lazyBackgroundImgTags(el) {
    return new Promise(async (resolve) => {
      const allSlottedImages = el.querySelectorAll("img[slot='background']");
      const allShadowImages = el.querySelectorAll("[slot='background'] img");
      const images = Array.from(allSlottedImages).concat(Array.from(allShadowImages));
      await lazyLoadSelectedImages(images);
      resolve();
    });
  }
  static lazyBackgroundImgComponents(el) {
    return new Promise(async (resolve) => {
      const allShadowImagesComponents = el.querySelectorAll(":scope > [slot='background'] deckgo-lazy-img");
      const images = Array.from(allShadowImagesComponents);
      await lazyLoadSelectedLazyImagesComponent(images);
      resolve();
    });
  }
  static loadSlots(el, slides, slotName, clone = true) {
    return new Promise(async (resolve) => {
      const background = el.querySelector(`:scope > [slot='${slotName}']`);
      if (!background) {
        resolve();
        return;
      }
      await this.lazyBackgroundImages(el);
      if (clone) {
        await this.cloneSlots(el, slides, slotName);
      }
      await this.showHideBackgroundSlot(el, clone);
      resolve();
    });
  }
  static async loadSlot(el, slide, slotName, clone = true) {
    const slot = el.querySelector(`:scope > [slot='${slotName}']`);
    if (!slot) {
      return;
    }
    await this.lazyBackgroundImages(el);
    if (clone) {
      await this.cloneSlot(el, slide, slotName);
    }
    await this.showHideBackgroundSlot(el, clone);
  }
  static showHideBackgroundSlot(el, cloneBackground) {
    return new Promise(async (resolve) => {
      const slider = el.shadowRoot.host;
      if (!slider) {
        resolve();
        return;
      }
      if (!cloneBackground) {
        slider.style.removeProperty('--background-display');
      }
      resolve();
    });
  }
  static cloneSlots(el, slides, slotName) {
    return new Promise((resolve) => {
      if (!slides || slides.length <= 0) {
        resolve();
        return;
      }
      const slotElement = el.querySelector(":scope > [slot='" + slotName + "']");
      if (slotElement) {
        slides.forEach((slide) => {
          this.appendSlot(slotElement, slide, slotName);
        });
      }
      resolve();
    });
  }
  static async cloneSlot(el, slide, slotName) {
    if (!slide) {
      return;
    }
    const slotElement = el.querySelector(":scope > [slot='" + slotName + "']");
    this.appendSlot(slotElement, slide, slotName);
  }
  static appendSlot(slotElement, slide, slotName) {
    if (!slotElement) {
      return;
    }
    const custom = slide.hasAttribute('custom-' + slotName);
    if (!custom) {
      const currentSlotElement = slide.querySelector(":scope > [slot='" + slotName + "']");
      if (currentSlotElement) {
        slide.removeChild(currentSlotElement);
      }
      slide.appendChild(slotElement.cloneNode(true));
    }
  }
  static removeSlots(slides, slotName) {
    return new Promise((resolve) => {
      if (!slides || slides.length <= 0) {
        resolve();
        return;
      }
      slides.forEach((slide) => {
        const custom = slide.hasAttribute('custom-' + slotName);
        if (!custom) {
          const currentSlotElement = slide.querySelector(":scope > [slot='" + slotName + "']");
          if (currentSlotElement) {
            slide.removeChild(currentSlotElement);
          }
        }
      });
      resolve();
    });
  }
}
