import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-4ed2a3e3.js';
import { d, c as containerSize } from './size.utils-4aae53d5.js';

const docCss = ":host{display:block;--ratio-A3:calc(297 / 420);--ratio-A4:calc(210 / 297);--ratio-A5:calc(148 / 210);--doc-size:calc(var(--doc-width) * (var(--doc-zoom, 100) / 100));min-height:var(--doc-size);width:calc(var(--doc-size) * var(--ratio-A4));padding:calc(var(--doc-size) * var(--doc-padding, 25) / 297);--font-size:calc(var(--doc-size) / 72);font-size:var(--font-size, 1em)}:host([size=A4][orientation=landscape]),:host([orientation=landscape]){width:var(--doc-size);min-height:calc(var(--doc-size) * var(--ratio-A4))}:host([size=A3]){width:calc(var(--doc-size) * var(--ratio-A3))}:host([size=A3][orientation=landscape]){width:var(--doc-size);min-height:calc(var(--doc-size) * var(--ratio-A3))}:host([size=A5]){width:calc(var(--doc-size) * var(--ratio-A5))}:host([size=A5][orientation=landscape]){width:var(--doc-size);min-height:calc(var(--doc-size) * var(--ratio-A5))}@media print{:host{--doc-size:297mm;--doc-zoom:100}:host([size=A3]){--doc-size:420mm}:host([size=A5]){--doc-size:210mm}}::slotted(*){outline:none;width:100%}";

let DeckGoDoc = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.sizeDidChange = createEvent(this, "sizeDidChange", 7);
    this.size = 'A4';
    this.orientation = 'portrait';
    this.debounceInitSize = d(() => this.initSize(), 100);
  }
  componentDidLoad() {
    this.initSize();
    this.initWindowResize();
  }
  disconnectedCallback() {
    window === null || window === void 0 ? void 0 : window.removeEventListener('resize', this.debounceInitSize);
  }
  onZoomChange() {
    this.debounceInitSize();
  }
  initSize() {
    const onRender = (_mutations, observer) => {
      observer.disconnect();
      this.sizeDidChange.emit(this.docSize);
    };
    const docObserver = new MutationObserver(onRender);
    docObserver.observe(this.el, { attributes: true });
    this.docSize = containerSize({ embedded: true, container: this.el });
  }
  initWindowResize() {
    window === null || window === void 0 ? void 0 : window.addEventListener('resize', this.debounceInitSize);
  }
  render() {
    const style = Object.assign(Object.assign({}, (this.zoom && { '--doc-zoom': `${this.zoom}` })), (this.docSize && { '--doc-width': `${this.docSize.width}px`, '--doc-height': `${this.docSize.height}px` }));
    return (h(Host, { style: style }, h("slot", null)));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "zoom": ["onZoomChange"]
  }; }
};
DeckGoDoc.style = docCss;

export { DeckGoDoc as deckgo_doc };
